nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Aoreg1

Struct Aoreg1 

#[repr(transparent)]
pub struct Aoreg1(pub u32);
General purpose always on domain data storage [Reset by: PoR, Brown Out Detectors Reset]

Tuple Fields

0: u32

Implementations

Source

impl Aoreg1

pub const fn por(&self) -> bool

The last chip reset was caused by a Power On Reset.

pub const fn set_por(&mut self, val: bool)

The last chip reset was caused by a Power On Reset.

pub const fn padreset(&self) -> bool

The last chip reset was caused by a Pin Reset.

pub const fn set_padreset(&mut self, val: bool)

The last chip reset was caused by a Pin Reset.

pub const fn bodreset(&self) -> bool

The last chip reset was caused by a Brown Out Detector (BoD), either VBAT BoD or Core Logic BoD.

pub const fn set_bodreset(&mut self, val: bool)

The last chip reset was caused by a Brown Out Detector (BoD), either VBAT BoD or Core Logic BoD.

pub const fn systemreset(&self) -> bool

The last chip reset was caused by a System Reset requested by the ARM CPU.

pub const fn set_systemreset(&mut self, val: bool)

The last chip reset was caused by a System Reset requested by the ARM CPU.

pub const fn wdtreset(&self) -> bool

The last chip reset was caused by the Watchdog Timer.

pub const fn set_wdtreset(&mut self, val: bool)

The last chip reset was caused by the Watchdog Timer.

pub const fn swrreset(&self) -> bool

The last chip reset was caused by a Software event.

pub const fn set_swrreset(&mut self, val: bool)

The last chip reset was caused by a Software event.

pub const fn dpdreset_wakeupio(&self) -> bool

The last chip reset was caused by a Wake-up I/O reset event during a Deep Power-Down mode.

pub const fn set_dpdreset_wakeupio(&mut self, val: bool)

The last chip reset was caused by a Wake-up I/O reset event during a Deep Power-Down mode.

pub const fn dpdreset_rtc(&self) -> bool

The last chip reset was caused by an RTC (either RTC Alarm or RTC wake up) reset event during a Deep Power-Down mode.

pub const fn set_dpdreset_rtc(&mut self, val: bool)

The last chip reset was caused by an RTC (either RTC Alarm or RTC wake up) reset event during a Deep Power-Down mode.

pub const fn dpdreset_ostimer(&self) -> bool

The last chip reset was caused by an OS Event Timer reset event during a Deep Power-Down mode.

pub const fn set_dpdreset_ostimer(&mut self, val: bool)

The last chip reset was caused by an OS Event Timer reset event during a Deep Power-Down mode.

pub const fn booterrorcounter(&self) -> u8

ROM Boot Fatal Error Counter.

pub const fn set_booterrorcounter(&mut self, val: u8)

ROM Boot Fatal Error Counter.