nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ldopmu

Struct Ldopmu 

#[repr(transparent)]
pub struct Ldopmu(pub u32);
Power Management Unit (PMU) and Always-On domains LDO control [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

Tuple Fields

0: u32

Implementations

Source

impl Ldopmu

pub const fn vadj(&self) -> Vadj

Sets the Always-On domain LDO output level.

pub const fn set_vadj(&mut self, val: Vadj)

Sets the Always-On domain LDO output level.

pub const fn vadj_pwd(&self) -> u8

Sets the Always-On domain LDO output level in all power down modes.

pub const fn set_vadj_pwd(&mut self, val: u8)

Sets the Always-On domain LDO output level in all power down modes.

pub const fn vadj_boost(&self) -> u8

Sets the Always-On domain LDO Boost output level.

pub const fn set_vadj_boost(&mut self, val: u8)

Sets the Always-On domain LDO Boost output level.

pub const fn vadj_boost_pwd(&self) -> u8

Sets the Always-On domain LDO Boost output level in all power down modes.

pub const fn set_vadj_boost_pwd(&mut self, val: u8)

Sets the Always-On domain LDO Boost output level in all power down modes.

pub const fn boost_ena(&self) -> bool

Control the LDO AO boost mode in ACTIVE mode.

pub const fn set_boost_ena(&mut self, val: bool)

Control the LDO AO boost mode in ACTIVE mode.

pub const fn boost_ena_pwd(&self) -> bool

Control the LDO AO boost mode in the different low power modes (DEEP SLEEP, POWERDOWN, and DEEP POWER DOWN).

pub const fn set_boost_ena_pwd(&mut self, val: bool)

Control the LDO AO boost mode in the different low power modes (DEEP SLEEP, POWERDOWN, and DEEP POWER DOWN).