#[repr(transparent)]pub struct Ostimer(pub u32);Expand description
OS Timer control register [Reset by: PoR, Brown Out Detectors Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Ostimer
impl Ostimer
Sourcepub const fn set_softreset(&mut self, val: bool)
pub const fn set_softreset(&mut self, val: bool)
Active high reset.
Sourcepub const fn clockenable(&self) -> bool
pub const fn clockenable(&self) -> bool
Enable OSTIMER 32 KHz clock.
Sourcepub const fn set_clockenable(&mut self, val: bool)
pub const fn set_clockenable(&mut self, val: bool)
Enable OSTIMER 32 KHz clock.
Sourcepub const fn dpdwakeupenable(&self) -> bool
pub const fn dpdwakeupenable(&self) -> bool
Wake up enable in Deep Power Down mode (To be used in Enable Deep Power Down mode).
Sourcepub const fn set_dpdwakeupenable(&mut self, val: bool)
pub const fn set_dpdwakeupenable(&mut self, val: bool)
Wake up enable in Deep Power Down mode (To be used in Enable Deep Power Down mode).
Sourcepub const fn osc32kpd(&self) -> bool
pub const fn osc32kpd(&self) -> bool
Oscilator 32KHz (either FRO32KHz or XTAL32KHz according to RTCOSC32K.
Sourcepub const fn set_osc32kpd(&mut self, val: bool)
pub const fn set_osc32kpd(&mut self, val: bool)
Oscilator 32KHz (either FRO32KHz or XTAL32KHz according to RTCOSC32K.