#[repr(transparent)]pub struct Pdruncfg0(pub u32);Expand description
Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Pdruncfg0
impl Pdruncfg0
Sourcepub const fn pden_bodvbat(&self) -> PdenBodvbat
pub const fn pden_bodvbat(&self) -> PdenBodvbat
Controls power to VBAT Brown Out Detector (BOD).
Sourcepub const fn set_pden_bodvbat(&mut self, val: PdenBodvbat)
pub const fn set_pden_bodvbat(&mut self, val: PdenBodvbat)
Controls power to VBAT Brown Out Detector (BOD).
Sourcepub const fn pden_fro32k(&self) -> PdenFro32k
pub const fn pden_fro32k(&self) -> PdenFro32k
Controls power to the Free Running Oscillator (FRO) 32 KHz.
Sourcepub const fn set_pden_fro32k(&mut self, val: PdenFro32k)
pub const fn set_pden_fro32k(&mut self, val: PdenFro32k)
Controls power to the Free Running Oscillator (FRO) 32 KHz.
Sourcepub const fn pden_xtal32k(&self) -> PdenXtal32k
pub const fn pden_xtal32k(&self) -> PdenXtal32k
Controls power to crystal 32 KHz.
Sourcepub const fn set_pden_xtal32k(&mut self, val: PdenXtal32k)
pub const fn set_pden_xtal32k(&mut self, val: PdenXtal32k)
Controls power to crystal 32 KHz.
Sourcepub const fn pden_xtal32m(&self) -> PdenXtal32m
pub const fn pden_xtal32m(&self) -> PdenXtal32m
Controls power to high speed crystal.
Sourcepub const fn set_pden_xtal32m(&mut self, val: PdenXtal32m)
pub const fn set_pden_xtal32m(&mut self, val: PdenXtal32m)
Controls power to high speed crystal.
Sourcepub const fn set_pden_pll0(&mut self, val: PdenPll0)
pub const fn set_pden_pll0(&mut self, val: PdenPll0)
Controls power to System PLL (also refered as PLL0).
Sourcepub const fn set_pden_pll1(&mut self, val: PdenPll1)
pub const fn set_pden_pll1(&mut self, val: PdenPll1)
Controls power to USB PLL (also refered as PLL1).
Sourcepub const fn pden_usbfsphy(&self) -> PdenUsbfsphy
pub const fn pden_usbfsphy(&self) -> PdenUsbfsphy
Controls power to USB Full Speed phy.
Sourcepub const fn set_pden_usbfsphy(&mut self, val: PdenUsbfsphy)
pub const fn set_pden_usbfsphy(&mut self, val: PdenUsbfsphy)
Controls power to USB Full Speed phy.
Sourcepub const fn pden_usbhsphy(&self) -> PdenUsbhsphy
pub const fn pden_usbhsphy(&self) -> PdenUsbhsphy
Controls power to USB High Speed Phy.
Sourcepub const fn set_pden_usbhsphy(&mut self, val: PdenUsbhsphy)
pub const fn set_pden_usbhsphy(&mut self, val: PdenUsbhsphy)
Controls power to USB High Speed Phy.
Sourcepub const fn set_pden_comp(&mut self, val: PdenComp)
pub const fn set_pden_comp(&mut self, val: PdenComp)
Controls power to Analog Comparator.
Sourcepub const fn pden_ldousbhs(&self) -> PdenLdousbhs
pub const fn pden_ldousbhs(&self) -> PdenLdousbhs
Controls power to USB high speed LDO.
Sourcepub const fn set_pden_ldousbhs(&mut self, val: PdenLdousbhs)
pub const fn set_pden_ldousbhs(&mut self, val: PdenLdousbhs)
Controls power to USB high speed LDO.
Sourcepub const fn pden_auxbias(&self) -> PdenAuxbias
pub const fn pden_auxbias(&self) -> PdenAuxbias
Controls power to auxiliary biasing (AUXBIAS)
Sourcepub const fn set_pden_auxbias(&mut self, val: PdenAuxbias)
pub const fn set_pden_auxbias(&mut self, val: PdenAuxbias)
Controls power to auxiliary biasing (AUXBIAS)
Sourcepub const fn pden_ldoxo32m(&self) -> PdenLdoxo32m
pub const fn pden_ldoxo32m(&self) -> PdenLdoxo32m
Controls power to high speed crystal LDO.
Sourcepub const fn set_pden_ldoxo32m(&mut self, val: PdenLdoxo32m)
pub const fn set_pden_ldoxo32m(&mut self, val: PdenLdoxo32m)
Controls power to high speed crystal LDO.
Sourcepub const fn pden_rng(&self) -> PdenRng
pub const fn pden_rng(&self) -> PdenRng
Controls power to all True Random Number Genetaor (TRNG) clock sources.
Sourcepub const fn set_pden_rng(&mut self, val: PdenRng)
pub const fn set_pden_rng(&mut self, val: PdenRng)
Controls power to all True Random Number Genetaor (TRNG) clock sources.
Sourcepub const fn pden_pll0_sscg(&self) -> PdenPll0Sscg
pub const fn pden_pll0_sscg(&self) -> PdenPll0Sscg
Controls power to System PLL (PLL0) Spread Spectrum module.
Sourcepub const fn set_pden_pll0_sscg(&mut self, val: PdenPll0Sscg)
pub const fn set_pden_pll0_sscg(&mut self, val: PdenPll0Sscg)
Controls power to System PLL (PLL0) Spread Spectrum module.