nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Pdruncfgclr0

Struct Pdruncfgclr0 

#[repr(transparent)]
pub struct Pdruncfgclr0(pub u32);
Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

Tuple Fields

0: u32

Implementations

Source

impl Pdruncfgclr0

pub const fn pdruncfgclr0(&self) -> u32

Writing ones to this register clears the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.

pub const fn set_pdruncfgclr0(&mut self, val: u32)

Writing ones to this register clears the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.