#[repr(transparent)]pub struct Pdruncfgset0(pub u32);Expand description
Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Pdruncfgset0
impl Pdruncfgset0
Sourcepub const fn pdruncfgset0(&self) -> u32
pub const fn pdruncfgset0(&self) -> u32
Writing ones to this register sets the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.
Sourcepub const fn set_pdruncfgset0(&mut self, val: u32)
pub const fn set_pdruncfgset0(&mut self, val: u32)
Writing ones to this register sets the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.