#[repr(transparent)]pub struct Rtcosc32k(pub u32);Expand description
RTC 1 KHZ and 1 Hz clocks source control register [Reset by: PoR, Brown Out Detectors Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Rtcosc32k
impl Rtcosc32k
Sourcepub const fn sel(&self) -> Sel
pub const fn sel(&self) -> Sel
Select the 32K oscillator to be used in Deep Power Down Mode for the RTC (either XTAL32KHz or FRO32KHz) .
Sourcepub const fn set_sel(&mut self, val: Sel)
pub const fn set_sel(&mut self, val: Sel)
Select the 32K oscillator to be used in Deep Power Down Mode for the RTC (either XTAL32KHz or FRO32KHz) .
Sourcepub const fn clk1khzdiv(&self) -> u8
pub const fn clk1khzdiv(&self) -> u8
Actual division ratio is : 28 + CLK1KHZDIV.
Sourcepub const fn set_clk1khzdiv(&mut self, val: u8)
pub const fn set_clk1khzdiv(&mut self, val: u8)
Actual division ratio is : 28 + CLK1KHZDIV.
Sourcepub const fn clk1khzdivupdatereq(&self) -> bool
pub const fn clk1khzdivupdatereq(&self) -> bool
RTC 1KHz clock Divider status flag.
Sourcepub const fn set_clk1khzdivupdatereq(&mut self, val: bool)
pub const fn set_clk1khzdivupdatereq(&mut self, val: bool)
RTC 1KHz clock Divider status flag.
Sourcepub const fn set_clk1hzdiv(&mut self, val: u16)
pub const fn set_clk1hzdiv(&mut self, val: u16)
Actual division ratio is : 31744 + CLK1HZDIV.
Sourcepub const fn clk1hzdivhalt(&self) -> bool
pub const fn clk1hzdivhalt(&self) -> bool
Halts the divider counter.
Sourcepub const fn set_clk1hzdivhalt(&mut self, val: bool)
pub const fn set_clk1hzdivhalt(&mut self, val: bool)
Halts the divider counter.
Sourcepub const fn clk1hzdivupdatereq(&self) -> bool
pub const fn clk1hzdivupdatereq(&self) -> bool
RTC 1Hz Divider status flag.
Sourcepub const fn set_clk1hzdivupdatereq(&mut self, val: bool)
pub const fn set_clk1hzdivupdatereq(&mut self, val: bool)
RTC 1Hz Divider status flag.