nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Wakeupioctrl

Struct Wakeupioctrl 

#[repr(transparent)]
pub struct Wakeupioctrl(pub u32);
Deep Power Down wake-up source [Reset by: PoR, Pin Reset, Software Reset]

Tuple Fields

0: u32

Implementations

Source

impl Wakeupioctrl

pub const fn risingedgewakeup0(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup0(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup0(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup0(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn risingedgewakeup1(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup1(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup1(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup1(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn risingedgewakeup2(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup2(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup2(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup2(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn risingedgewakeup3(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup3(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup3(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup3(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn modewakeup0(&self) -> bool

Configure wake up I/O 0 in Deep Power Down mode

pub const fn set_modewakeup0(&mut self, val: bool)

Configure wake up I/O 0 in Deep Power Down mode

pub const fn modewakeup1(&self) -> bool

Configure wake up I/O 1 in Deep Power Down mode

pub const fn set_modewakeup1(&mut self, val: bool)

Configure wake up I/O 1 in Deep Power Down mode

pub const fn modewakeup2(&self) -> bool

Configure wake up I/O 2 in Deep Power Down mode

pub const fn set_modewakeup2(&mut self, val: bool)

Configure wake up I/O 2 in Deep Power Down mode

pub const fn modewakeup3(&self) -> bool

Configure wake up I/O 3 in Deep Power Down mode

pub const fn set_modewakeup3(&mut self, val: bool)

Configure wake up I/O 3 in Deep Power Down mode