#[repr(transparent)]pub struct Ldopmu(pub u32);Expand description
Power Management Unit (PMU) and Always-On domains LDO control [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Ldopmu
impl Ldopmu
Sourcepub const fn vadj_pwd(&self) -> u8
pub const fn vadj_pwd(&self) -> u8
Sets the Always-On domain LDO output level in all power down modes.
Sourcepub const fn set_vadj_pwd(&mut self, val: u8)
pub const fn set_vadj_pwd(&mut self, val: u8)
Sets the Always-On domain LDO output level in all power down modes.
Sourcepub const fn vadj_boost(&self) -> u8
pub const fn vadj_boost(&self) -> u8
Sets the Always-On domain LDO Boost output level.
Sourcepub const fn set_vadj_boost(&mut self, val: u8)
pub const fn set_vadj_boost(&mut self, val: u8)
Sets the Always-On domain LDO Boost output level.
Sourcepub const fn vadj_boost_pwd(&self) -> u8
pub const fn vadj_boost_pwd(&self) -> u8
Sets the Always-On domain LDO Boost output level in all power down modes.
Sourcepub const fn set_vadj_boost_pwd(&mut self, val: u8)
pub const fn set_vadj_boost_pwd(&mut self, val: u8)
Sets the Always-On domain LDO Boost output level in all power down modes.
Sourcepub const fn set_boost_ena(&mut self, val: bool)
pub const fn set_boost_ena(&mut self, val: bool)
Control the LDO AO boost mode in ACTIVE mode.
Sourcepub const fn boost_ena_pwd(&self) -> bool
pub const fn boost_ena_pwd(&self) -> bool
Control the LDO AO boost mode in the different low power modes (DEEP SLEEP, POWERDOWN, and DEEP POWER DOWN).
Sourcepub const fn set_boost_ena_pwd(&mut self, val: bool)
pub const fn set_boost_ena_pwd(&mut self, val: bool)
Control the LDO AO boost mode in the different low power modes (DEEP SLEEP, POWERDOWN, and DEEP POWER DOWN).