#[repr(transparent)]pub struct Pdruncfgclr0(pub u32);Expand description
Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Pdruncfgclr0
impl Pdruncfgclr0
Sourcepub const fn pdruncfgclr0(&self) -> u32
pub const fn pdruncfgclr0(&self) -> u32
Writing ones to this register clears the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.
Sourcepub const fn set_pdruncfgclr0(&mut self, val: u32)
pub const fn set_pdruncfgclr0(&mut self, val: u32)
Writing ones to this register clears the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.